pub struct ProtoCache { /* private fields */ }Implementations
Sourceimpl ProtoCache
impl ProtoCache
pub fn new() -> Self
Sourcepub fn with_max_entries(max_entries: usize) -> Self
pub fn with_max_entries(max_entries: usize) -> Self
Create a cache with a custom maximum number of entries.
When the cache reaches capacity, the oldest entry is evicted (FIFO).
pub fn get_or_compile<P, I>( &self, proto_path: P, includes: I, ) -> Result<DescriptorPool, ProtoCompileError>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool